---------------------------------------------------------------------------
--- VARS ------------------------------------------------------------------
---------------------------------------------------------------------------

-- This lists all commands that the system understands, and maps them to
-- functions that should be used to activate them.
commandMap = 
{
    -- This special entry doesn't map to a command, but the editor uses
    -- it when the command specified doesn't exist.
    ["ErrorFallback"]    = commandNotKnown,

    -- Commands in the player section
    ["Player"]           = commandPlayer,
    ["PlayerView"]       = commandPlayerView,
    ["PlayerProfile"]    = commandPlayerProfile,
    ["PlayerNew"]        = commandPlayerNew,
    ["PlayerDelete"]     = commandPlayerDelete,
    ["PlayerProperties"] = commandPlayerProperties,

    -- Commands in the designer section
    ["Designer"]           = commandDesigner,
    ["DesignerAdd"]        = commandDesigner,
    ["DesignerDelete"]     = commandDesigner,
    ["DesignerProperties"] = commandDesignerProperties,

    -- Commands in the publisher section
    ["Publisher"]           = commandPublisher,
    ["PublisherAdd"]        = commandPublisher,
    ["PublisherDelete"]     = commandPublisher,
    ["PublisherProperties"] = commandPublisherProperties,

    -- Commands in the category section
    ["Category"]           = commandCategory,
    ["CategoryAdd"]        = commandCategory,
    ["CategoryDelete"]     = commandCategory,
    ["CategoryProperties"] = commandCategoryProperties,

    -- Commands in the game section
    ["Game"]               = commandGame,
    ["GameNew"]            = commandGameNew,
    ["GameDelete"]         = commandGameDelete,
    ["GameProperties"]     = commandGameProperties,
    ["GameView"]           = commandGameView,
    ["GameViewDesigner"]   = commandGameViewDesigner,
    ["GameViewPublisher"]  = commandGameViewPublisher,
    ["GameViewCategory"]   = commandGameViewCategory,
    ["GameViewExpansions"] = commandGameViewExpansion,

    -- Commands in the session section
    ["Session"]                   = commandSession,
    ["SessionAdd"]                = commandSessionAdd,
    ["SessionViewGame"]           = commandSessionViewGame,
    ["SessionProperties"]         = commandSessionProperties,
    ["SessionDetails"]            = commandSessionDetails,
    ["SessionDelete"]             = commandSessionDelete,
    ["SessionViewWinsByPlayer"]   = commandSessionViewWinsByPlayer,
    ["SessionViewLossesByPlayer"] = commandSessionViewLossesByPlayer,

    -- Commands in the tool section
    ["Tool"]           = commandTool,
    ["ToolGameFinder"] = commandToolGameFinder,

    -- Commands in the configuration section
    ["Configure"]        = commandConfiguration,
    ["ConfigureChange"]  = commandConfiguration,

    -- Commands in the activity log section
    ["Logs"]       = commandLogs,
    ["LogsDelete"] = commandLogsDelete,
}

-- This creates a list of URL's that can be used to link from one part of
-- the system to another.
urls = 
{
    -- Designer related URL's. 
    ["designerProperties"] = env.scriptName .. "?command=DesignerProperties&designerID=",
    ["gamesByDesigner"]    = env.scriptName .. "?command=GameViewDesigner&designerID=",

    -- Publisher related URL's.
    ["publisherProperties"] = env.scriptName .. "?command=PublisherProperties&publisherID=",
    ["gamesByPublisher"]    = env.scriptName .. "?command=GameViewPublisher&publisherID=",

    -- Category related URL'S
    ["categoryProperties"]  = env.scriptName .. "?command=CategoryProperties&categoryID=",
    ["gamesByCategory"]     = env.scriptName .. "?command=GameViewCategory&categoryID=",

    -- Player related URL's
    ["playerProperties"]    = env.scriptName .. "?command=PlayerProperties&playerID=",
    ["playerProfile"]       = env.scriptName .. "?command=PlayerView&playerID=",

    -- Session Report relates URL's
    ["sessionDetails"]       = env.scriptName .. "?command=SessionDetails&sessionID=",
    ["sessionProperties"]    = env.scriptName .. "?command=SessionProperties&sessionID=",
    ["sessionAdd"]           = env.scriptName .. "?command=SessionAdd&gameID=",
    ["gamesBySession"]       = env.scriptName .. "?command=SessionViewGame&gameID=",
    ["sessionsByPlayerWin"]  = env.scriptName .. "?command=SessionViewWinsByPlayer&playerID=",
    ["sessionsByPlayerLoss"] = env.scriptName .. "?command=SessionViewLossesByPlayer&playerID=",

    -- Game relates URL's
    ["gameDetails"]         = env.scriptName .. "?command=GameView&gameID=",
    ["gameProperties"]      = env.scriptName .. "?command=GameProperties&gameID=",
    ["gamesByExpansion"]    = env.scriptName .. "?command=GameViewExpansions&gameID=",

    -- Other URL'S
    ["bgg"]                 = "http://www.boardgamegeek.com/game/",
}

---------------------------------------------------------------------------
--- MAIN CODE -------------------------------------------------------------
---------------------------------------------------------------------------


