---------------------------------------------------------------------------
--- LOCAL VARS ------------------------------------------------------------
---------------------------------------------------------------------------

local ERR_LOG_NOPRIVDEL = [[You are not allowed to alter the system logs.]]
local ERR_LOG_NOPRIVVIEW = [[You are not allowed to view the system logs.]]

local thisPageSection = "LOGS"                         

---------------------------------------------------------------------------
--- FUNCTIONS -------------------------------------------------------------
---------------------------------------------------------------------------

-- This is the main function to view logs, and also to delete them
function commandLogs (db)
    -- Header for the page
    generatePageHeader (thisPageSection, nil, "logsView")

    -- Generate a button to delete logs
    if userInfo.canEditLog then
        html.form:singleButtonForm ("Delete Logs" , "LogsDelete" , env.scriptName , "POST" , nil, nil, "log")
        html:addText ("<P>")
    end

    -- Check to see if the user can view the log or not.
    if userInfo.canViewLog == false then
        -- Say what they tried to do
        addLog (db , "Attempted to view system log")

        -- Add some error text, and then return.
        html:addText (errorText (ERR_LOG_NOPRIVVIEW) , "<P>")
        return
    end
          
    -- Open a table for the values
    html.table:open (nil, "100%", nil, nil, "5", "logList")

    -- Display a heading for all of the rows
    html.table:heading (nil, "97%", nil, "LEFT", "TOP")
    html:addText ("Message")
    html.table:heading (true, "1%", nil, "LEFT", "TOP")
    html:addText ("Player")
    html.table:heading (true, "1%", nil, "LEFT", "TOP")
    html:addText ("IP Address")
    html.table:heading (true, "1%", nil, "LEFT", "TOP")
    html:addText ("Time")

    local colorStr

    -- Get all rows. The order of the items returned is the reverse order
    -- in which the items were inserted, so they'll display last item
    -- first.
    local logItems = getActivityLog (db)
    for rowIndex, row in logItems do
        -- If this is an even numbered row, make the background
        -- white. Otherwise, leave it as is.
        if math.mod (rowIndex , 2) == 0 then colorStr = "White" else colorStr = nil  end
        html.table:newRow (nil, nil, nil, colorStr)

        -- The message comes straight out of the database
        html.table:cell (nil, "97%" , nil , "LEFT" , "TOP")
        html:addText (row.message)

        -- The playerID. If it is 0, then insert system. If
        -- it converts to a number, then use the number to look
        -- up the actual player. Otherwise, just output it as
        -- is (it is probably a deleted player)
        html.table:cell (true, "1%" , nil , "CENTER" , "TOP")

        -- Try to look up the user by the ID. If this fails, then
        -- the ID must not exist or isn't a number, so just insert
        -- it as is.
        local userName = nicknameByID (db , row.playerID) or row.playerID
        html:addText (userName)
              
        -- The IP address of this user at the time
        html.table:cell (true, "1%" , nil , "CENTER" , "TOP")
        html:addText (row.ip)

        -- What time this event occured.
        html.table:cell (true, "1%" , nil , "CENTER" , "TOP")
        html:addText (os.date ("%m/%d/%Y %H:%M:%S %Z" , row.eventTime))
    end

    -- Close the table now
    html.table:close ()

    -- Now, saw that they viewed the log. This one is inserted after, so that
    -- people viewing the log don't immediately realize that viewing is also
    -- tracked (unless there is one there already). Also things seem cleaner
    -- thi way.
    addLog (db , "Viewed system log")
end

---------------------------------------------------------------------------

-- This is the command that allows for the deletion of the system logs
function commandLogsDelete (db)
    -- Header for the page
    generatePageHeader (thisPageSection, "Delete System Logs", "logsDelete")

    -- Generate a button to go back to the main Log page
    html.form:singleButtonForm ("Return to Log Page" , "Logs" , env.scriptName , "POST" , nil, nil, "log")
    html:addText ("<P>")

    -- If this user cannot edit logs, then say so now and return.
    if userInfo.canEditLog == false then
        -- Say what they tried to do
        addLog (db , "Attempted to erase system log")

        -- Add some error text, and then return
        html:addText (errorText (ERR_LOG_NOPRIVDEL) , "<P>")
        return
    end

    -- Now, check to see if the form was submitted. The extra field "verified" is
    -- present only when the form is submitted. Note that the above will stop anyone
    -- from deleting the logs, even if they fake a URL that will do the evil deed.
    local formArgs = collectFormArguments ({"verified"})

    -- If the form hasn't been submitted yet, then display a form that will
    -- allow someone to do so.
    if formArgs == nil then
        -- Start a form to ask the user if they really want to erase the logs
        html.form:open (env.scriptName , "POST", nil, nil)

        -- Mini-form
        html.form:submit ("Button", "Erase System Log", "log")
        html.form:hidden ("command", "LogsDelete")
        html.form:hidden ("verified", "YES")

        -- Close form now
        html.form:close ()
    else
        -- Erase all logs in the system
        emptyActivityLog (db)
        addLog (db , "Erased the system log")
        html:addText (successText ("Erased the system log successfully."))
    end
end

---------------------------------------------------------------------------
--- MAIN CODE -------------------------------------------------------------
---------------------------------------------------------------------------

