---------------------------------------------------------------------------
--- VARS ------------------------------------------------------------------
---------------------------------------------------------------------------

-- This lists the menu items that appear in the left side menu whenever
-- the page is viewed. The first column is the command that will be 
-- returned when the button is pressed. The second is the text that
-- will be used for the text of the link.
local menuItems = 
{
    {"Player"    , "Players"},
    {"Designer"  , "Designers"},
    {"Publisher" , "Publishers"},
    {"Category"  , "Categories"},
    {"Game"      , "Games"},
    {"Session"   , "Sessions"},
    {"Tool"      , "Tools"},
    {"Configure" , "Configure"},
    {"Logs"      , "Activity Log"},
    {"Logout"    , "Logout"}
}

---------------------------------------------------------------------------
--- FUNCTIONS -------------------------------------------------------------
---------------------------------------------------------------------------

-- This helper function generates a single menu item entry
local generateMenuEntry = function (command, text, index)
    -- The url for this menu entry
    local linkURL = env.scriptName .. "?command=" .. command

    -- By default, this command isn't current
    local cellClass = "normal"

    -- Is there a command submitted already?
    if CGI.formData.command ~= nil then
        -- If we can find the command that we're generating at the
        -- beginning of the form command, then this command is current.
        -- This allows us to cover sub-commands in groupings.
        if string.find (CGI.formData.command , "^" .. command) ~= nil then
            cellClass = "current"
        end
    end

    -- If index is 1, then this is the first thing, to tack "Top" onto the cell class.
    if index == 1 then cellClass = cellClass .. "Top" end

    -- Now, open a cell. We want nowrap and to specify the class above. 
    html.table:cell (true, nil, nil, "CENTER" , "CENTER", cellClass)

    -- Generate the link and seperate it from the others
    html:link (linkURL , text);
end

---------------------------------------------------------------------------

-- This helper function generates a table entry which contains the gamedb
-- version number and release date.
local generateVersionInfo = function ()
    -- Open the cell using the special version property so that it's not
    -- outlined.
    html.table:cell (true, nil, nil, "LEFT", "TOP", "version")

    -- gamedb version and link
    html:link ("http://www.nurdz.com/gamedb.shtml", "GameDB", "_new")
    html:addText (" v. ", GAMEDB_VERSION, "<br>\n")

    -- luaweb version and link
    html:link ("http://www.nurdz.com/luaweb.shtml", "LuaWeb", "_new")
    html:addText (" v. ", luaweb_version)
end

---------------------------------------------------------------------------

-- Called to generate the menu portion of the page, which is enclosed in a
-- Mini table. Each cell in this table contains a link. The cell that contains
-- the current command uses a different style; the background is a different
-- color and the text of the link is bigger.
function generateMenu ()
    -- Open the table that will hold the menu.
    html.table:open ("0" , nil, nil, "0" , "0", "menutable")

    -- Generate all menu items
    for index,data in ipairs (menuItems) do
        generateMenuEntry (data[1] , data[2], index)
        html.table:newRow ()
    end

    -- Generate the version information
    generateVersionInfo ()

    -- All done
    html.table:close ()
end

---------------------------------------------------------------------------

