---------------------------------------------------------------------------
--- VARS ------------------------------------------------------------------
---------------------------------------------------------------------------


---------------------------------------------------------------------------
--- FUNCTIONS -------------------------------------------------------------
---------------------------------------------------------------------------

-- Help for the base game page
function gamesBaseHelp (topic, helpURL)
    setPageTitle ("Game List")

    html:addText ([[
<H3>Game List</H3>

This page displays the complete list of games currently entered into the
system. This is an abbreviated game list, and so the category, designer
and publisher listed here is not a complete list, and instead represent
the very first of each to be assigned to the game.<p>

The name of each game leads to a detailed game view, which includes the
other fields in the game, such as description, playtime, and so on.<p>

If you have the proper 
<a href="?topic=playerProperties">permissions</a>
in the system, you may also be able to add, edit and delete games from
the system from this page.  When a game is deleted, all session reports
for that game are also removed from the system. This will have an impact
on the games played information stored for each player as well.
    ]])
end

---------------------------------------------------------------------------

-- Help for the add game page
function gamesAddHelp (topic, helpURL)
    setPageTitle ("Add a Game")

    html:addText ([[
<H3>Add a Game</H3>

This page allows you to add a new game entry to the system. The fields present
allow you to set:

<UL>

<LI> <b>Name:</b> What this game will be named in the system.<p>

<LI> <b>Expansion for:</b> If this game is an expansion for another game, select that game
from the dropdown menu.<p>

<LI> <b>BGG ID:</b> If desired, you may enter the BoardGameGeek gameID of this game in this field.
If this value is not 0, this will be used by the system to generate a link to the BGG game page
for this game.<p>

<LI> <b>Players:</b> The range of players that this game supports. If there is a set number of players,
enter the same value in both fields.<p>

<LI> <b>Play Time:</b> The time it takes to play this game. Normally this value would be taken from the
manufacturer, but if you know that value to be inaccurate, you could put anything here.

<LI> <b>Categories:</b> Select from the available categories for this game. If you need to enter more than
three categories, you will need to add the game to the database with the first three. After the addition,
three extra fields will be shown. Additionally, if you are allowed to add categories to the system, each
dropdown will also include a text box, in which you can add new categories directly. If you specify a category
that already exists, that category will be used instead of adding a new one.<p>

<LI> <b>Designers:</b> Select from the available designers in the system. This section works identically to
the category section of the page.<p>

<LI> <b>Publishers:</b> Select from the available publixhers in the system. This section works identically to
the category section of the page.<p>

<LI> <b>Description:</b> Enter a description of the game. This could be something you make up yourself, the
description of the game from the back of the box, etc.<p>

</UL>
    ]])
end

---------------------------------------------------------------------------

-- Help for the edit game page
function gamesEditHelp (topic, helpURL)
    setPageTitle ("Edit a Game")

    html:addText ([[
<H3>Edit a Game</H3>

This page allows you to edit the properties of an existing game entry in the
system. See the
<a href="?topic=gamesAdd">game addition</a>
page for more information on all of the fields and what they mean.<p>

In addition, a control bar is present at the top of the editing interface,
which allows you to view the current game, step through the games in the system in alphabetical
order, open up the boardgamegeek page associated with this game (if it has a BGG game ID set), or
add/view session reports for this game.<p>

Some of these actions may not be available for you if you do not have the
proper
    ]])

    html:link (helpURL .. "playerProperties", "permissions")

    html:addText (" in the system.")
end    

---------------------------------------------------------------------------

-- Help for the view game page
function gamesViewHelp (topic, helpURL)
    setPageTitle ("View a Game")

    html:addText ([[
<H3>View a Game</H3>

This page provides a detailed view of a game in the system. All of the information
available on a game is displayed here; all designers, publishers and categories, the 
player range, play time and a description of the game. <p>

If there are any session reports for this game which include a play duration, the average playtime of
the game will be displayed next to the play time on record in the database, for
comparison purposes.<p>

If this game has any expansions listed in the database, this will be indicated, along with a 
link to allow you to view all expansions. In a similar vein, if this game is an expansion for
some other game, then that will be indicated, along with a link to allow you to view the base
game.<p>

Each designer, publisher and category is a link which will show you all games associated
with that particular data (e.g. All games designed by Alan Moon.).

In addition, a control bar is present at the top of the editing interface,
which allows you to edit the current game, step through the games in the system in alphabetical
order, open up the boardgamegeek page associated with this game (if it has a BGG game ID set), or
add/view session reports for this game.<p>

Some of these actions may not be available for you if you do not have the
proper
<a href="?topic=playerProperties">permissions</a>
in the system.
    ]])
end    

---------------------------------------------------------------------------

-- Help for the game expansions page
function gamesExpansionsHelp (topic, helpURL)
    setPageTitle ("Game Expansion List")

    html:addText ([[
<H3>Game Expansion List</H3>

This page displays all games in the system which are marked as being the
expansion of a particular game in the system. This is an abbreviated game list, and so
the category, designer and publisher listed here is not a complete list, and
instead represent the very first of each to be assigned to a game.
    ]])
end

---------------------------------------------------------------------------

