---------------------------------------------------------------------------
--- VARS ------------------------------------------------------------------
---------------------------------------------------------------------------


---------------------------------------------------------------------------
--- FUNCTIONS -------------------------------------------------------------
---------------------------------------------------------------------------

-- Base player help, for the main player page
function basePlayerHelp (topic, helpURL)
    setPageTitle ("Players")

    html:addText ([[
<H3>What are Players?</H3>

In the GameDB, users of the system are known as Players. Each player has
their own unique username and password, and permissions to perform various
actions in the system. In addition, some aspects of the system, such as
session reporting, require the players involved to be registered in the system.<p>

This page lists all of the known players in the system, sorted alphabetically by
their names. In addition, the username of the player (for login purposes) and the
number of games that this player has won (and their win percentage) is also displayed.<p>

If you have the required permissions, you may also be able to select players for deletion (see below).

<H3>Player Actions</H3>

There are several actions which can be performed on players in the system
via this section of gameDB. Some of these items, flagged with a <b><i>[perm]</i></b>
flag, require that you have been granted appropriate access by the site
administrator.<p>

<OL>

<LI>
<A href="?topic=playerProfile">View/Edit profile:</a>
&nbsp; Each player has an associated profile, which includes their name, homepage,
email address, and information regarding the games that they have played. You can view
any players profile by clicking on their name in the player list. You also have the
ability to edit your own profile. This allows you to change your password, email address,
and homepage. Note that information on games played and win/loss records are not directly
editable by this section of the page.<p>

<LI>
<A href="?topic=playerAdd">Add a player:</a>

&nbsp; <b><i>[perm]</i></b> If you have the required 
<a href="?topic=playerProperties">permissions</a>
, you can add new players to the system. These people will then be allowed to
log into the system. This is the only way to get new players into the system for
purposes such as session reporting.

The system records who added each user to the system, for accounting purposes.<p>

<LI>
<LI>Delete a player:
&nbsp; <b><i>[perm]</i></b> If you have the required 
<a href="?topic=playerProperties">permissions</a>,
you can remove existing players from the system. This will completely remove all
information regarding this player, so be careful! In particular, any session reports
which feature that player will be modified to appear as if that player did not play.
If that player was the winner of any games, this can cause unexpected changes to 
games played statistics.<p>

To delete a player or players, check the box next to each player to remove from the
system, and then click the delete button at the bottom of the list. You will be asked
if you are sure you want to perform the deletion. <b>Be Careful!</b> Player deletions
are not undo-able, so all information will be lost. Note that the checkboxes next to players and
the delete button will not be present if you do not have the permissions required to delete players.<p>


<LI>
<A href="?topic=playerProperties">Modify player properties:</a>
[&nbsp; <b><i>[perm]</i></b> If you have the required
<a href="?topic=playerProperties">permissions</a>,
you can edit the permissions of other players in the system, including yourself.<p>

Permissions are access controls, which allow you to customize what each person is allowed
to modify in the system. Although it is not possible to restrict access to general system
information, like the game list or designers list, it is possible to retrict access to adding
new records, or editing existing records.<p>

To modify properties for yourself or another player, click the Properties link next to the
player's name. This link will only be present if you have the permissions neccesary to perform
this action.<p>

</OL>
    ]])
end

---------------------------------------------------------------------------

-- Help for the player profile page (editing)
function playerProfileHelp (topic, helpURL)
    setPageTitle ("Player Profile Editing")

    html:addText ([[
<H3>Edit your Profile</H3>

This page allows you to edit your player profile. This includes your login information
(nickname and password), as well as your name, email address and homepage URL.

Your name, email and password are visible to other players in the system when they
<a href="?topic=playerView">view your profile</a>.
In addition, a link to your homepage is displayed at the top of every page.<p>

In order to change any of your profile items, you must enter your current password,
as a security precaution. 
    ]])
end

---------------------------------------------------------------------------

-- Help for the add a player page 
function playerAddHelp (topic, helpURL)
    setPageTitle ("Player Additions")

    html:addText ([[
<H3>Add a Player</H3>

This page allows you to add a new player to the system. The information you provide
here will become this player's initial
<a href="?topic=playerProfile">player profile</a>
information. The new player will have all of their 
<a href="?topic=playerProperties">player permissions</a>
turned off by default.<p>

The name, nickname, and password fields are mandatory, while the email address and
homepage fields may be left blank if desired. The player may modify their profile
information to change any of these fields at a later date.<p>

Note that the nickname and password will be this player's initial login information.
    ]])
end

---------------------------------------------------------------------------

-- Help for the add a player page 
function playerViewProfileHelp (topic, helpURL)
    setPageTitle ("Player Profiles")

    html:addText ([[
<H3>View Player Profile</H3>

This page shows you the profile and play information for a player in the
system. Available information from the profile of the given player can
be seen here.<p>

In addition, if this player is part of any session reports, information on
games played will also be displayed on the page. This includes the game most
recently won and lost, as well as a complete record of every game played, and
the percentage of wins at any particular game.
    ]])
end

---------------------------------------------------------------------------

-- Help for the add a player page 
function playerPropertiesHelp (topic, helpURL)
    setPageTitle ("Player Properties")

    html:addText ([[
<H3>Player Properties</H3>

Each player in the system has their own set of permissions which outlines 
what that player can/cannot manipulate in the system. Each time a new player
is added, all of their permissions are turned off, which allows them only read
access to all information except their own profile information.<p>

The available options on any pages in the system may be modified by the
player viewing that page. For example, the Players page will not have 
a button that allows for the addition of players if that permission is not
available.<p>

The available permissions are:

<UL>

<LI> <b>Add new players:</b> Allows this player to add new players to the system. Newly
added players have all permissions turned off by default.<p>

<LI> <b>Delete existing players:</b> Allows this player to delete other players from the
system. When a player is deleted, all records in session reports are deleted
as well. This may cause a session report to contain the wrong number of people,
or possibly have no winner recorded, if the deleted player is the winner.<p>

<LI> <b>Edit player properties:</b> Allows this player to edit the permissions list for any
player in the system. Please note that it is possible to remove permissions from
yourself, including this one. This means you may accidentally remove your own ability
to modify player permissions, with no way to get it back without the help of some other
user with this permission set.<p>

<LI> <b>Add/Edit game designers:</b> Allows this player to add new game designers to the system,
as well as edit the names assigned to existing designers. When this permission is set,
the game addition screen will include text boxes which allow for "on the fly" designer
additions, to save input time.<p>

<LI> <b>Add/Edit game publishers:</b> Allows this player to add new game publishers to the system,
as well as edit the names assigned to existing publishers. When this permission is set,
the game addition screen will include text boxes which allow for "on the fly" publisher
additions, to save input time.<p>

<LI> <b>Add/Edit game categories:</b> Allows this player to add new game categories to the system,
as well as edit the names assigned to existing categories. When this permission is set,
the game addition screen will include text boxes which allow for "on the fly" category
additions, to save input time.<p>

<LI> <b>Add new games:</b> Allows this player to add new games to the system. Note that there is a
seperate property which allows for the editing of currently existing games. This is split
apart so that it is possible to have a group of people which only have "editorial" powers.<p>

<LI> <b>Edit existing games:</b> Allows this player to edit games that are in the system. Note that
there is a seperate property which allows for the addition of new games to the system. This is split
apart so that it is possible to have a group of people which only have "editorial" powers.<p>

<LI> <b>Add new session reports:</b> Allows this player to add new session reports to the system. Note that there
is a seperate property which allows for the editing of currently existing session reports. This is split
apart so that it is possible to have a group of people which only have "editorial" powers.<p>

<LI> <b>Edit existing session reports:</b> Allows this player to edit session reports that are already in the system. Note that there
is a seperate property which allows for the addition of new session reports. This is split
apart so that it is possible to have a group of people which only have "editorial" powers.<p>

<LI> <b>Configure the system:</b> Allows this player the ability to modify the configuration of gamedb.<p>       

<LI> <b>View the event log:</b> Allows this player to view the system event log. This lists all content additions
and modifications that have been made in the system, including when the change was made and who made it <p>

<LI> <b>Empty the event log:</b> Allows this player to empty out the system event lot. This lists all content additions
and modifications that have been made in the system, including when the change was made and who made it <p>

<LI> <b>Raw Database access:</b> Currently, this property is unused. When implemented, it will allow for arbitrary
access to the underlying game database via standard SQL statements. In that case, having this property enabled
is the same as having every other property turned on. This is very dangerous and should not be enabled for anyone
except the main system administrator account.<p>

</UL>
    ]])
end

---------------------------------------------------------------------------
