---------------------------------------------------------------------------
--- VARS ------------------------------------------------------------------
---------------------------------------------------------------------------


---------------------------------------------------------------------------
--- FUNCTIONS -------------------------------------------------------------
---------------------------------------------------------------------------

-- Help for the base sessions page
function sessionsBaseHelp (topic, helpURL)
    setPageTitle ("Session Report List")

    html:addText ([[
<H3>Session Report List</H3>

This page displays the complete list of session reports which are currently
entered into the system. The list displays the date that the game took place,
how long it took to play, as well as who won. <p>

Clicking on the name of the game will take you to the game page for that
particular game.<p>

Clicking on the name of the winner will show you the complete list of games
where that player is listed as a winner. <p>

More information on each session report, including the complete list of who played, 
scores, and the report itself, is available by clicking on the details link.<p>

If you have the proper
<a href="?topic=playerProperties">permissions</a>
in the system, you may also be able to add, edit, and delete session reports
from the system from this page. Deleted session reports will have an impact on
the games played information stored for each player.
    ]])
end

---------------------------------------------------------------------------

-- Help for the sessions by winner page
function sessionsForPlayerWinHelp (topic, helpURL)
    setPageTitle ("Winning Session Report List for a Player")

    html:addText ([[
<H3>Winning Session Report List for a Player</H3>

This page displays the complete list of session reports which are currently
entered in the system in which a particular player is listed as a winner
of the game.<p>

The list displays the same information that the
<a href="?topic=sessionsBase">regular session list</a>
page displays.
    ]])
end

---------------------------------------------------------------------------

-- Help for the sessions by loser page
function sessionsForPlayerLossHelp (topic, helpURL)
    setPageTitle ("Losing Session Report List for a Player")

    html:addText ([[
<H3>Losing Session Report List for a Player</H3>

This page displays the complete list of session reports which are currently
entered in the system in which a particular player is listed as not winning
the game.<p>

The list displays the same information that the
<a href="?topic=sessionsBase">regular session list</a>
page displays.
    ]])
end


---------------------------------------------------------------------------

-- Help for the add session page
function sessionsAddHelp (topic, helpURL)
    setPageTitle ("Add a Session Report")

    html:addText ([[
<H3>Add a Session Report</H3>

This page allows you to add a new session report to the system. Depending on
how you arrived at this page, you may be asked to select the game that the
session report will be for. Some links in the system will provide this information
for you.

The fields present allow you to set:

<UL>

<LI>
<b>Game:</b> The game that this session report will be for. Next to the name of the
game is a link to the game name as it appeared when the page was generated. This allows
you to jump directly to the page for this game, and also acts as a reminder as to what
game the report was for, if you change the dropdown and later change your mind.<p>

<LI> <b>Date:</b> The date and time that the game was played. This will be set to the current
date and time at the time that you added the session report.<p>

<LI> <b>Duration:</b> How long the game took to play. You may enter this field in minutes (i.e. 120)
or you may use an HH:MM notation (i.e. 2:00). When there is no game duration set, or if there is
an error in your input (e.g. not a number), the duration will be displayed as ??:??.<p>

When durations are added to session reports for a game, a calculated average play time will be
displayed on that game's main page.<p>

<LI> <b>Players:</b> For each player in the game, select the player from the dropdown list, enter their
score in the game (as appropriate), and flag each winner by checking the checkbox. The score field
is used only for informational purposes, and there can be more than one winner (in case of ties). <p>

The information here is used to calculate games played and win/loss statistics for each player involved
in the game.<p>

The system uses the number of players listed in the game's entry to determine how many player dropdown
boxes there should be.<p>

<LI> <b>Notes:</b> This is where the actual body of the session report is entered.<p>       

</UL>
    ]])
end

---------------------------------------------------------------------------

-- Help for the edit session page
function sessionsEditHelp (topic, helpURL)
    setPageTitle ("Edit a Session Report")

    html:addText ([[
<H3>Edit a Session Report</H3>

This page allows you to edit the properties of an existing session report in the
system. See the
<a href="?topic=sessionsAdd">session addition</a>
page for more information on all of the fields and what they mean.<p>

In addition, a control bar is present at the top of the editing interface,
which allows you to view the current session report, step through the sessions in the system in chronological 
order and add/view session new reports for the game that this session report is for.<p>

Some of these actions may not be available for you if you do not have the
proper
<a href="?topic=playerProperties">permissions</a>
in the system.
    ]])
end    

---------------------------------------------------------------------------

-- Help for the session game page
function sessionsViewHelp (topic, helpURL)
    setPageTitle ("View a Session Report")

    html:addText ([[
<H3>View a Session Report</H3>

This page provides a detailed view of a session report in the system. All of the information
available from the session report is displayed here; the game played, date and time of the game, how long
the game took to play, the players involved, and the actual report of the session.<p>

In addition, a control bar is present at the top of the editing interface,
which allows you to edit the current report, step through the reports in the system in chronological
order and add/view session reports for the game this report is for.<p>

Some of these actions may not be available for you if you do not have the
proper
<a href="?topic=playerProperties">permissions</a>
in the system.
    ]])
end    

---------------------------------------------------------------------------

-- Help for the session list for a game page
function sessionsForGameHelp (topic, helpURL)
    setPageTitle ("Session Report List for a Game")

    html:addText ([[
<H3>Session Report List for a Game</H3>

This page lists all of the session reports that are currently recorded for a
particular game in the system. This view is similar to the view on the
<a href="?topic=sessionsBase">session report</a>
page, but the list is constrained to reports for a specific game.       
    ]])
end    

---------------------------------------------------------------------------

