#!./lua-web2

-- Load up the main config file, so that we can get the database
-- filename.
LUA_PATH = "./?"
cfg = require ("gamedb.cfg")
LUA_PATH = cfg.codeDir .. "?.lua"

local db,errStr = sqlite3.open (cfg.databaseFilename)

function donePage ()
    db:close ()
    html:endPage ()
end

-- Set the title of the page
html:setTitle ("Initialize DataBase")

-- If the Database wasn't opened, then complain and return.
if db == nil then
    html:addText ("Unable to open db: " , errStr)
    donePage ()
    return
end

-- The answer to our question, as well as if the form was submitted or not.
local answer = ""
local wasSubmitted = "no"

if CGI.parsedMultipartData ~= nil then
    if CGI.parsedMultipartData.command ~= nil then
        answer = CGI.parsedMultipartData.command

        -- If the answer is "yes" or "no", then consider the form submitted.
        -- Anything else leave it alone. This allows us to submit to this form
        -- from the main DB form.
        if answer == "yes" or answer == "no" then wasSubmitted = "yes" end
    end
end

-- If the form wasn't submitted, then close the page and return.
if wasSubmitted == "no" then
    html:addText ([[
This operation will ensure that all of the required tables for gamedb are installed into the
database, and pre-filled out with default values. Doing this will completely wipe out any 
tables that may already exist, including the data stored within them. This operation should
only be performed once, when the system is initially being set up.<P>

Are you sure you want to proceed with this operation and re-initialize the database?<P>]])

    html.table:open ()
    html.table:cell ()
    -- If the form was not submitted, then make one.
    html.form:singleButtonForm ("Yes, re-initialize the database", "yes", env.scriptName, "POST", "multipart/form-data")
    html.table:cell ()
    html.form:singleButtonForm ("No, I changed my mind", "no", env.scriptName, "POST", "multipart/form-data")
    html.table:close ()

    donePage ()
    return
end

-- The form was submitted. if the answer was NO, then do nothing.
if answer == "no" then
    html:addText ("Database left alone.")
    html.form:singleButtonForm ("View database", nil, cfg.baseURL .. "/viewdb.lua", "POST", "multipart/form-data")
    donePage ()
    return
end

-- Make sure the answer is not ambiguous. This is for safety sake
if answer ~= "yes" then
    html:addText ("I don't know what to do!")
    donePage ()
    return
end


-- This table should contain a list of SQL needed to create and initialize a table, with a key that is that
-- table's name. 
tableInfo = require ("tableDefinitions")

for name,sql in pairs (tableInfo) do
    html:addText ("Dropping and recreating table " , name , "...")
    html:flushPage ()
    db:dropTable (name)
    if db:exec (sql) ~= nil then html:addText ('<FONT COLOR="GREEN">DONE</FONT><BR>') else html:addText ('<FONT COLOR="RED">ERROR</FONT><BR>') end
end

-- We have to fix up the first log to put in the correct IP address and time now.
local ipAddr = env.remoteAddr
if ipAddr == nil then ipAddr = "UNKNOWN" end
local eventTime = tostring (os.time ())

db:execSQL ("UPDATE Logs SET ip = ?, eventTime = ? where logID = 1" , ipAddr, eventTime)

html:addText ("<P>Database initialization is complete!\n")

-- Close the database and end the page
html.form:singleButtonForm ("View database", nil, cfg.baseURL .. "/viewdb.lua", "POST", "multipart/form-data")

donePage ()

