#!./lua-web2

-- Load up the main config file, so that we can get the database
-- filename.
LUA_PATH = "./?"
cfg = require ("gamedb.cfg")
LUA_PATH = cfg.codeDir .. "?.lua"

local db,errStr = sqlite3.open (cfg.databaseFilename)

function donePage ()
    db:close ()
    html:endPage ()
end

-- Set the title of the page
html:setTitle ("DB Web Page")

-- If the Database wasn't opened, then complain and return.
if db == nil then
    html:addText ("Unable to open db: " , errStr)
    donePage ()
    return
end

-- The SQL that we're working with, and if a form was submitted.
local sql = ""
local truncate = ""
local wasSubmitted = "no"

if CGI.parsedMultipartData ~= nil then
    if CGI.parsedMultipartData.command == "Clear SQL" then
        CGI.parsedMultipartData.sql = nil
    end
    
    if CGI.parsedMultipartData.command == "List Tables" then
        CGI.parsedMultipartData.sql = 'SELECT tbl_name,sql from sqlite_master where type = "table"'
    end

    truncate = CGI.parsedMultipartData.truncate

    if CGI.parsedMultipartData.sql ~= nil then 
        sql = CGI.parsedMultipartData.sql 
        wasSubmitted = "yes"
    end
end

-- Special. If there is a command of ViewTable, then view the contents of the
-- given table, or sqlite_master if none is given. We do this here instead of
-- above because these commands will be generated by regular links (not posted
-- form data).
if CGI.formData.command == "ViewTable" then
    local tableName = CGI.formData.tableName or "sqlite_master"

    -- Set up the SQL and pretend that it was submitted
    sql = 'SELECT * from ' .. tableName
    wasSubmitted = "yes"
end

-- Generate a form
html.form:open (env.scriptName, "POST" , "multipart/form-data")
html.form:textArea ("sql" , sql , "60" , "10")
html:addText ("<BR>")
html.form:submit ("command" , "Execute SQL")
html.form:submit ("command" , "Clear SQL")
html.form:submit ("command" , "List Tables")
html.form:reset ("Revert SQL")
html.form:checkbox ("truncate" , "yes" , truncate)
html:addText ("Truncate long column values")
html.form:close ()
html.form:singleButtonForm ("Initialize database", nil,  cfg.baseURL .. "/initDB.lua", "POST", "multipart/form-data")

local baseLink = env.scriptName .. "?command=ViewTable&tableName="

html.table:open (nil , "80%")
html.table:caption ("View contents of table:" , "CENTER")

local tableCount = 0

for row in db:SQLrows ("SELECT tbl_name FROM sqlite_master WHERE type='table' ORDER BY tbl_name") do
    -- Output this table in a cell
    html.table:cell (nil, nil, nil, "CENTER" , "TOP")
    html:link (baseLink .. row.tbl_name , row.tbl_name)
    html:addText ("&nbsp; &nbsp;")

    -- Count a table up
    tableCount = tableCount + 1

    -- When tableCount hits 6, start a new row.
    if tableCount == 6 then
        tableCount = 0
        html.table:newRow ()
    end
end

-- Now, if tableCount is not 0, there are an odd number of tables,
-- and we need a cell that will pad everything out.
if tableCount ~= 0 then
    -- Subtract from 6 the value in tableCount, to get how many cells we
    -- need to pad by.
    tableCount = 6 - tableCount

    html.table:cell (nil, nil, nil, nil, nil, nil, nil, nil, tostring (tableCount))
    html:addText ("&nbsp;");
end

-- Close the table table
html.table:close ()

-- If the form wasn't submitted, then close the page and return.
if wasSubmitted == "no" then
    donePage ()
    return
end

-- Prepare the SQL statement for execution
statement, errStr = db:prepare (sql)

-- Did the prepare fail?
if statement == nil then
    -- Prepare failed, so say why
    html:addText ('<FONT COLOR="red" SIZE="+1">')
    html:addText ("Error preparing statement: " , errStr , "</FONT><P>")
else
    -- Output the SQL that is being executed
    html:addText ("<PRE>" , sql , "<PRE><P>\n")

    -- Count the number of handles in the SQL statement. IF the number of handles
    -- is more than 1, OR the handle count is 1 but the column count is 0, then
    -- just output the SQL that was executed and do nothing else. In the first case,
    -- trying to display results will fail. In the second case, there won't be any.
    if table.getn (statement.handles) == 1 and (statement:column_count () ~= 0) then
        -- Open a table 
        html.table:open (nil , "100%" , nil , "3" , "3")

        -- Get an array of columns and types of the columns. This works even though
        -- the statement hasn't been executed because the virtual machine has to know
        -- what columns are going to be returned back when the statement IS executed.
        --
        -- We also need to determine how many columns there are.
        --
        -- These will fail with an error if the statement contains more than one SQL statement.
        -- In particular, this means that you can't run 2 select statements one after the other
        -- (so do them seperately), or you can't execute 2 statements where one is a select and
        -- one is not, or you can't try to display the results of 2 non-select queries.
        local columns  = statement:column_names ()
        local types    = statement:column_decltypes ()
        local colCount = statement:column_count ()
        local rowCount = 0

        -- Manually start a row for the headings, so that we can format the color.
        html.table:newRow (nil , nil , nil , "black")

        -- Output the column names in one row.
        for index,name in columns do
            html.table:heading ("nowrap" , "1%" , nil , "center" , "top")
            html:addText ('<FONT COLOR="white">' , name)

            -- If there is a type string, then append it. In SQLite the type is informational
            -- only since everything stored is a string, so it's not really needed.
            if types[index] ~= "" then  html:addText ("(" , types[index] , ")") end

            html:addText ('</FONT>')
        end

        -- The statement has no columns, so execute the SQL instead.
        if colCount == 0 then
            result,errStr = db:exec (sql)
        else
            -- Now  execute the statement and output stuff
            for row in statement:irows () do
                local width = 100
                local colorStr = "#99CCFF"

                -- Count this as a row
                rowCount = rowCount + 1

                -- If this is an odd numbered row, then dump the color
                if math.mod (rowCount , 2) == 1 then colorStr = nil end
                
                -- Start a new row and assumed 100% width and the given color
                html.table:newRow (nil, nil, nil, colorStr)

                -- row is an array of data, so iterate over it.
                for index,data in ipairs (row) do
                    -- This block of code sets up the width of the current column. Each column is 1% of
                    -- the total width of the table at minimum, and the last column is whatever % is left.
                    -- This makes the browser render the table with all columns except the last one only as
                    -- wide as needed, while the last column expands to fill up the rest of the table.
                    local widthStr = "1%"
                    if index == colCount then
                        widthStr = tostring(width) .. "%"
                    else
                        width = width - 1
                    end

                    -- Start a new cell using the provided width, then dump out the data.
                    html.table:cell ("nowrap" , widthStr , nil , "left" , "top")

                    -- If the contents are excessively long, don't display them if that option
                    -- is turned on.
                    local columnText = data
                    
                    if truncate ~= nil then
                        if string.len (columnText) > 64 then
                            columnText = string.sub (columnText , 1 , 64) .. "..."
                        end
                    end

                    html:addText (columnText)
                end
            end
        end

         -- All done
        html.table:close ()
    else
        -- Execute the SQL
        result,errStr = db:exec (sql)

        -- No result table was output. Say why. If there are two or more statements, then the reason is
        -- too many statements. Otherwise the reason was no columns, so say the statements displayed no data.
        if table.getn (statement.handles) > 1 then
            html:addText ("No results will be displayed because multiple statements are being executed.<P>\n")
        else
            html:addText ("Statement returns no results.<P>\n")
        end
    end
end

-- Close the database and end the page
donePage ()

